summaryrefslogtreecommitdiffstats
path: root/parts/classview/classtooldlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/classview/classtooldlg.h')
-rw-r--r--parts/classview/classtooldlg.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/parts/classview/classtooldlg.h b/parts/classview/classtooldlg.h
index 01c86f3b..a33c7f2b 100644
--- a/parts/classview/classtooldlg.h
+++ b/parts/classview/classtooldlg.h
@@ -27,9 +27,10 @@ class ClassStore;
class ParsedClass;
-class ClassToolDialog : public QWidget
+class ClassToolDialog : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
enum Operations { ViewParents, ViewChildren, ViewClients, ViewSuppliers,
@@ -44,17 +45,17 @@ public slots:
/** View nothing. */
void viewNone();
/** View the parents of the current class. */
void viewParents();
/** View the children of the current class. */
void viewChildren();
/** View all classes that has this class as an attribute. */
void viewClients();
/** View all classes that this class has as attributes. */
void viewSuppliers();
/** View methods in this class and parents. */
void viewMethods();
/** View attributes in this class and parents. */
void viewAttributes();
private slots:
@@ -74,8 +75,8 @@ private:
ClassToolWidget *class_tree;
TQComboBox *class_combo;
- TQToolButton *parents_button;
- TQToolButton *children_button;
+ TQToolButton *tqparents_button;
+ TQToolButton *tqchildren_button;
TQToolButton *clients_button;
TQToolButton *suppliers_button;
TQToolButton *methods_button;
@@ -44,17 +45,17 @@ public slots:
/** View nothing. */
void viewNone();
- /** View the parents of the current class. */
+ /** View the tqparents of the current class. */
void viewParents();
@@ -44,17 +45,17 @@ public slots:
void viewParents();
- /** View the children of the current class. */
+ /** View the tqchildren of the current class. */
void viewChildren();
/** View all classes that has this class as an attribute. */
@@ -44,17 +45,17 @@ public slots:
/** View all classes that this class has as attributes. */
void viewSuppliers();
- /** View methods in this class and parents. */
+ /** View methods in this class and tqparents. */
void viewMethods();
@@ -44,17 +45,17 @@ public slots:
void viewMethods();
- /** View attributes in this class and parents. */
+ /** View attributes in this class and tqparents. */
void viewAttributes();
private slots: